@@ -31,6 +31,10 @@ class TimestampNotFound(Exception):
     """Timestamp service does not have a timestasmp for a given block."""
 
 
+class BadTimestampValueReturned(Exception):
+    """Timestamp does not look good."""
+
+
 # For typing.Protocol see https://stackoverflow.com/questions/68472236/type-hint-for-callable-that-takes-kwargs
 class ProgressUpdate(Protocol):
     """Informs any listener about the state of an event scan.
@@ -163,6 +167,8 @@ def extract_events(
 
         if extract_timestamps is not None:
             timestamps = extract_timestamps(web3, start_block, end_block)
+            if timestamps is None:
+                raise BadTimestampValueReturned("extract_timestamps returned None")
         else:
             timestamps = None
 
@@ -187,15 +193,18 @@ def extract_events(
                 assert timestamp is not None, f"Timestamp missing for block number {block_number}, hash {block_hash}"
                 log["timestamp"] = timestamp
             else:
-                if timestamps:
+                if timestamps is not None:
                     try:
-                        log["timestamp"] = timestamps[block_hash] if extract_timestamps else None
+                        log["timestamp"] = timestamps[block_hash]
+                        if type(log["timestamp"]) not in (int, float):
+                            raise BadTimestampValueReturned(f"Timestamp was not int or float: {type(log['timestamp'])}: {type(log['timestamp'])}")
                     except KeyError as e:
                         raise TimestampNotFound(f"EVM event reader cannot match timestamp. Timestamp missing for block number {block_number:,}, hash {block_hash}, our timestamp table has {len(timestamps)} blocks") from e
                 else:
                     # Not set, because reorg mon and timestamp extractor not provided,
                     # the caller must do the timestamp resolution themselves
                     log["timestamp"] = None
+
             yield log
 
 
@@ -342,6 +351,9 @@ def read_events(
     :param reorg_mon:
         If passed, use this instance to monitor and raise chain reorganisation exceptions.
 
+    :return:
+        Iterate over :py:class:`LogResult` instances for each event matched in
+        the filter.
     """
 
     assert type(start_block) == int
@@ -354,7 +366,7 @@ def read_events(
 
     # Construct our bloom filter
     if filter is None:
-        assert events is None, "Cannot pass both filter and events"
+        assert events is not None, "Cannot pass both filter and events"
         filter = prepare_filter(events)
 
     last_timestamp = None
@@ -482,6 +494,10 @@ def read_events_concurrent(
     :param reorg_mon:
         If passed, use this instance to monitor and raise chain reorganisation exceptions.
 
+    :return:
+        Iterate over :py:class:`LogResult` instances for each event matched in
+        the filter.
+
     """
 
     assert not executor._executor._shutdown, "ThreadPoolExecutor has been shut down"
@@ -495,7 +511,7 @@ def read_events_concurrent(
 
     # Construct our bloom filter
     if filter is None:
-        assert events is None, "Cannot pass both filter and events"
+        assert events is not None, "Cannot pass both filter and events"
         filter = prepare_filter(events)
 
     # For futureproof usage see
@@ -508,7 +524,8 @@ def read_events_concurrent(
     completed_tasks: Dict[int, tuple] = {}
 
     for block_num in range(start_block, end_block + 1, chunk_size):
-        last_of_chunk = min(end_block, block_num + chunk_size) - 1
+        last_of_chunk = min(end_block, block_num + chunk_size - 1)
+
         task_list[block_num] = (
             block_num,
             last_of_chunk,
@@ -523,7 +540,7 @@ def read_events_concurrent(
 
     logger.debug("Submitted %d tasks", len(task_list))
 
-    processed_chunks: Set[int]= set()
+    processed_chunks: Set[int] = set()
 
     # Complete the tasks.
     # Always guarantee the block order for the caller,
