@@ -2,6 +2,7 @@
 
 import logging
 import threading
+from typing import Optional
 
 import futureproof
 from web3 import Web3
@@ -24,11 +25,23 @@ def get_worker_web3() -> Web3:
     return _thread_local_storage.web3
 
 
-def create_thread_pool_executor(factory: Web3Factory, context: LogContext, max_workers=16) -> futureproof.ThreadPoolExecutor:
+def create_thread_pool_executor(factory: Web3Factory, context: Optional[LogContext] = None, max_workers=16) -> futureproof.ThreadPoolExecutor:
     """Create a thread pool executor.
 
     All pool members have the thread locals initialized at start,
     so that there is Web3 connection available.
+
+    :param factory:
+        The factory that provides web3 connection
+        for each threaad after a thread has been launched.
+
+    :param context:
+        Event reader context.
+
+        If you want to pass something extra for the event reader.
+
+    :param max_workers:
+        How many threads are allocated for futureproof pool.
     """
 
     def init():
